@@ -367,7 +367,7 @@ sending events to the correct L<Test2::Hub> instance.
 =head1 SYNOPSIS
 
 In general you will not be creating contexts directly. To obtain a context you
-should always use C<context()> which is exported by the L<Test2> module.
+should always use C<context()> which is exported by the L<Test2::API> module.
 
     use Test2::API qw/context/;
 
@@ -403,7 +403,7 @@ Creating your own context via C<< Test2::API::Context->new() >> will almost neve
 produce a desirable result. Use C<context()> which is exported by L<Test2>.
 
 There are a handful of cases where a tool author may want to create a new
-congtext by hand, which is why the C<new> method exists. Unless you really know
+context by hand, which is why the C<new> method exists. Unless you really know
 what you are doing you should avoid this.
 
 =item You MUST always release the context when done with it
@@ -496,12 +496,12 @@ This will return the L<Test2::Util::Trace> instance used by the context.
 
 Sometimes you have a context that is not current, and you want things to use it
 as the current one. In these cases you can call
-L<< $ctx->do_in_context(sub { ... }) >>. The codeblock will be run, and
+C<< $ctx->do_in_context(sub { ... }) >>. The codeblock will be run, and
 anything inside of it that looks for a context will find the one on which the
 method was called.
 
-This B<DOES NOT> effect context on other hubs, only the hub used by the context
-will be effected.
+This B<DOES NOT> affect context on other hubs, only the hub used by the context
+will be affected.
 
     my $ctx = ...;
     $ctx->do_in_context(sub {
